@@ -68,7 +68,11 @@ QString KTNEFPropertySet::findNamedProp(const QString &name, const QString &fall
     for (QMap<int, KTNEFProperty *>::Iterator it = d->properties_.begin(), protEnd = d->properties_.end(); it != protEnd; ++it) {
         if ((*it)->name().isValid()) {
             QString s;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             if ((*it)->name().type() == QVariant::String) {
+#else
+            if ((*it)->name().metaType().id() == QMetaType::QString) {
+#endif
                 s = (*it)->name().toString();
             } else {
                 s = QString::asprintf("0X%04X", (*it)->name().toUInt());
@@ -76,7 +80,11 @@ QString KTNEFPropertySet::findNamedProp(const QString &name, const QString &fall
 
             if (s.toUpper() == name.toUpper()) {
                 QVariant value = (*it)->value();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                 if (value.type() == QVariant::List) {
+#else
+                if (value.metaType().id() == QMetaType::QVariantList) {
+#endif
                     QList<QVariant> l = value.toList();
                     s.clear();
                     for (QList<QVariant>::ConstIterator lit = l.constBegin(), litEnd = l.constEnd(); lit != litEnd; ++lit) {
@@ -139,7 +147,7 @@ void KTNEFPropertySet::addAttribute(int key, int type, const QVariant &value, bo
             return;
         }
     }
-    auto *p = new KTNEFProperty(key, type, value, QVariant());
+    auto p = new KTNEFProperty(key, type, value, QVariant());
     d->attributes_[p->key()] = p;
 }
 
